data - MultiMolecule
Author: MultiMolecule
Description: Neural Networks for RNA, DNA, and Protein

跳转至

# data

`data` provides a collection of data processing utilities for handling data.

While `datasets` is a powerful library for managing datasets, it is a general-purpose tool that may not cover all the specific functionalities of scientific applications.

The `data` package is designed to complement `datasets` by offering additional data processing utilities that are commonly used in scientific tasks.

## Key Features

- Data Pre-Processing: `Dataset` is a base class that provides a consistent interface for pre-processing data. It includes methods for identifying the data columns and tasks, tokenizing sequences, and batching.
- Data Loading: `PandasDataset` is a subclass of `Dataset` that loads data in a `DataFrame` compatible format. This provides a convenient way to work with many common data formats, including CSV, JSON, and Excel files.

2024-05-09 09:39:45

#### Cookie Consent

We use cookies to recognize your repeated visits and preferences, as well as to measure the effectiveness of our documentation and whether users find what they're searching for. With your consent, you're helping us to make our documentation better. Please check out our Privacy Notice for more information.

- Google Analytics
- GitHub

管理设定